@@ -10,15 +10,15 @@ use std::{
 pub struct PhysicsPlugin;
 
 impl Plugin for PhysicsPlugin {
-    fn build(&self, app: &mut AppBuilder) {
+    fn build(&self, app: &mut App) {
         app.add_event::<CollisionEvent>()
-            .add_system(collision_detection.system());
+            .add_system(collision_detection);
     }
 }
 
 /// This is the struct that is generated when a collision occurs. Collisions only occur between two
 /// [Sprite]s which:
-/// - have colliders (you can use the `collider_creator` example to create your own colliders)
+/// - have colliders (you can use the `collider` example to create your own colliders)
 /// - have their `collision` flags set to `true`.
 #[derive(Debug, Clone)]
 pub struct CollisionEvent {
@@ -282,6 +282,13 @@ impl Collider {
             .map(|&v| v * sprite.scale + sprite.translation) // scale & translation
             .collect()
     }
+    pub fn points(&self) -> Vec<Vec2> {
+        if let Self::Poly(points) = self {
+            points.clone()
+        } else {
+            Vec::with_capacity(0)
+        }
+    }
     pub fn colliding(sprite1: &Sprite, sprite2: &Sprite) -> bool {
         use Collider::*;
         if let NoCollider = sprite1.collider {
